@@ -21,7 +21,7 @@ blob = {
     storage_key: "<secured string>"
     storage_connection_string: "<secured string>"
     sas_key: "<secured string>"
-    sas_url: "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T00:06:34Z&st=2020-04-04T16:06:34Z&spr=https&sig=pfpsr7LS6OBBAJdeNNegP9SUYSCF2yDwqFr8SZ3hS5M%3D"
+    sas_url: "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-10-10&ss=bfqt&srt=sco&sp=rwdlacupx&se=2021-05-05T23:11:11Z&st=2020-05-05T15:11:11Z&spr=https&sig=LwTi%2BFlw4kLJWYip8oINKHOnwkNMZOE3HbYVrcQ32qg%3D"
     container_name: "unittest-taz"
     path: "test.csv"
     sas_url_path: "test_sas_url.csv"
@@ -65,3 +65,12 @@ dls = {
 
 dls_glob = {
 }
+
+tables = {
+    storage_account_name: "zstalrsdvllogdev01"
+    storage_key: "<secured string>"
+    storage_connection_string: "<secured string>"
+    sas_key: "<secured string>"
+    sas_url: "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-10-10&ss=bfqt&srt=sco&sp=rwdlacupx&se=2021-05-05T23:11:11Z&st=2020-05-05T15:11:11Z&spr=https&sig=LwTi%2BFlw4kLJWYip8oINKHOnwkNMZOE3HbYVrcQ32qg%3D"
+    table_name: "taztest"
+}
